# pyddos

A simple DDoS testing library in Python. It provides various attack methods such as UDP flood, SYN flood, and Botnet simulation for testing and simulation purposes.

## Features
- **UDP Flood**: Launch a UDP flood attack to test the resilience of a server.
- **SYN Flood**: Simulate a SYN flood attack.
- **Botnet**: Simulate a botnet attack by using multiple threads.

## Installation

You can install `pyddos` via `pip` from PyPI:

```bash
pip install pyddos
```